==> jboss-osgi-husky-1.0.0-sources.jar: org/jboss/osgi/husky/runtime/Connector.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.osgi.husky.runtime;


import java.util.List;

import org.jboss.osgi.husky.Request;
import org.jboss.osgi.husky.Response;

// $Id: Connector.java 91202 2009-07-14 11:34:29Z thomas.diesler@jboss.com $

/**
 * A Connector is the receiving side of a test request.
 * 
 * It processes the test request by dispatching it to one of
 * the associated {@link PackageListener}s.
 * 
 * It is an error if no {@link PackageListener} can handle the 
 * incomming test request.
 * 
 * @author Thomas.Diesler@jboss.com
 * @since 16-May-2009
 */
public interface Connector
{
   /**
    * Handles the test request by dispatching to one of the 
    * associated {@link PackageListener}s. 
    *
    * @throws RuntimeException if no {@link PackageListener} can 
    */
   Response process(Request req) throws ClassNotFoundException;
   
   /**
    * Get the set of registered {@link PackageListener}s for this connector
    */
   List<PackageListener> getPackageListeners();
   
   /**
    * Add a {@link PackageListener} to this connector
    */
   void addPackageListener(PackageListener listener);
   
   /**
    * Remove a {@link PackageListener} from this connector
    */
   void removePackageListener(PackageListener listener);
}

==> jboss-osgi-husky-1.0.1-sources.jar: org/jboss/osgi/husky/runtime/Connector.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.osgi.husky.runtime;


import java.util.List;

import org.jboss.osgi.husky.Request;
import org.jboss.osgi.husky.Response;

// $Id: Connector.java 94593 2009-10-09 12:44:30Z thomas.diesler@jboss.com $

/**
 * A Connector is the receiving side of a test request.
 * 
 * It processes the test request by dispatching it to one of
 * the associated {@link PackageListener}s.
 * 
 * It is an error if no {@link PackageListener} can handle the 
 * incomming test request.
 * 
 * @author Thomas.Diesler@jboss.com
 * @since 16-May-2009
 */
public interface Connector
{
   /**
    * Handles the test request by dispatching to one of the 
    * associated {@link PackageListener}s. 
    *
    * @throws RuntimeException if no {@link PackageListener} can be found
    */
   Response process(Request req) throws ClassNotFoundException;
   
   /**
    * Get the set of registered {@link PackageListener}s for this connector
    */
   List<PackageListener> getPackageListeners();
   
   /**
    * Add a {@link PackageListener} to this connector
    */
   void addPackageListener(PackageListener listener);
   
   /**
    * Remove a {@link PackageListener} from this connector
    */
   void removePackageListener(PackageListener listener);
}
